@@ -31,8 +31,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice *device)
     _errorLine = 0;
 
     // find codec for file
-    //    bool hadCodec;
-    const auto codecName = codecForDevice(device /*, &hadCodec*/);
+    const auto codecName = codecForDevice(device);
     QTextStream stream(device);
     stream.seek(0);
 
@@ -48,15 +47,9 @@ ConversionStatus GettextImportPlugin::load(QIODevice *device)
         stream.setString(&decodedData, QIODevice::ReadOnly);
     }
 
-    // QIODevice *dev = stream.device();
-    // int fileSize = dev->size();
-
     // if somethings goes wrong with the parsing, we don't have deleted the old contents
     CatalogItem tempHeader;
 
-    // qCDebug(LOKALIZE_LOG) << "start parsing...";
-    //     QTime aaa;
-    //     aaa.start();
     // first read header
     const ConversionStatus status = readEntry(stream);
 
@@ -70,8 +63,6 @@ ConversionStatus GettextImportPlugin::load(QIODevice *device)
     }
 
     bool reconstructedHeader = !_msgid.isEmpty() && !_msgid.first().isEmpty();
-    // qCWarning(LOKALIZE_LOG) << "HEADER MSGID: " << _msgid;
-    // qCWarning(LOKALIZE_LOG) << "HEADER MSGSTR: " << _msgstr;
     if (Q_UNLIKELY(reconstructedHeader)) {
         // The header must have an empty msgid
         qCWarning(LOKALIZE_LOG) << "Header entry has non-empty msgid. Creating a temporary header! " << _msgid;
@@ -90,10 +81,6 @@ ConversionStatus GettextImportPlugin::load(QIODevice *device)
         tempHeader.setMsgstr(_msgstr);
         tempHeader.setComment(_comment);
     }
-    //    if(tempHeader.isFuzzy())
-    //    {
-    //       tempHeader.removeFuzzy();
-    //    }
 
     // check if header seems to indicate docbook content generated by xml2pot
     const bool docbookContent = tempHeader.msgstr().contains(QStringLiteral("application/x-xml2pot"));
@@ -101,7 +88,6 @@ ConversionStatus GettextImportPlugin::load(QIODevice *device)
     // now parse the rest of the file
     uint counter = 0;
     QList<int> errorIndex;
-    // bool recoveredError=false;
     bool docbookFile = false;
 
     ExtraDataSaver _extraDataSaver;
@@ -132,7 +118,6 @@ ConversionStatus GettextImportPlugin::load(QIODevice *device)
             }
         } else if (Q_UNLIKELY(success == RECOVERED_PARSE_ERROR)) {
             qCDebug(LOKALIZE_LOG) << "Recovered parse error in entry: " << counter;
-            // recoveredError=true;
             errorIndex.append(counter);
 
             CatalogItem tempCatItem;
@@ -162,34 +147,17 @@ ConversionStatus GettextImportPlugin::load(QIODevice *device)
         return PARSE_ERROR;
     }
 
-    // qCDebug(LOKALIZE_LOG) << " ready";
-
     // We have successfully loaded the file (perhaps with recovered errors)
 
-    //    qCWarning(LOKALIZE_LOG) << " done in " << aaa.elapsed() <<_extraDataSaver->extraData.size() << endl;
-
     setGeneratedFromDocbook(docbookContent || docbookFile);
     setHeader(tempHeader);
     setCatalogExtraData(_extraDataSaver.extraData);
     setErrorIndex(errorIndex);
     setCodec(codecName);
-    // setMimeTypes( "text/x-gettext-translation" );
-#if 0
-    if (Q_UNLIKELY(recoveredErrorInHeader)) {
-        qCDebug(LOKALIZE_LOG) << " Returning: header error";
-        return RECOVERED_HEADER_ERROR;
-    } else if (Q_UNLIKELY(recoveredError)) {
-        qCDebug(LOKALIZE_LOG) << " Returning: recovered parse error";
-        return RECOVERED_PARSE_ERROR;
-    } else
-#endif
-    {
-        // qCDebug(LOKALIZE_LOG) << " Returning: OK! :-)";
-        return OK;
-    }
+    return OK;
 }
 
-QByteArray GettextImportPlugin::codecForDevice(QIODevice *device /*, bool* hadCodec*/)
+QByteArray GettextImportPlugin::codecForDevice(QIODevice *device)
 {
     QTextStream stream(device);
     stream.seek(0);
@@ -248,7 +216,6 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream &stream)
 
 ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
 {
-    // qCDebug(LOKALIZE_LOG) << " START";
     enum {
         Begin,
         Comment,
@@ -259,7 +226,6 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
 
     bool error = false;
     bool recoverableError = false;
-    // bool seenMsgctxt=false;
     _msgstr.clear();
     _msgstr.append(QString());
     _msgid.clear();
@@ -275,7 +241,6 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
 
     while (!stream.atEnd()) {
         _errorLine++;
-        // line=stream.readLine();
         if (!_bufferedLine.isEmpty()) {
             line = _bufferedLine;
             _bufferedLine.clear();
@@ -320,7 +285,6 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
                 line.remove(_rxMsgLineRemEndQuote);
                 _msgctxt = line;
                 _msgctxtPresent = true;
-                // seenMsgctxt=true;
             } else if (line.contains(_rxMsgId)) {
                 part = Msgid;
 
@@ -333,7 +297,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
 
             }
             // one of the quotation marks is missing
-            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgIdBorked))) {
+            else if (Q_UNLIKELY(line.contains(_rxMsgIdBorked))) {
                 part = Msgid;
 
                 // remove quotes at beginning and the end of the lines
@@ -368,7 +332,6 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
                 line.remove(_rxMsgLineRemEndQuote);
                 _msgctxt = line;
                 _msgctxtPresent = true;
-                // seenMsgctxt=true;
             } else if (line.contains(_rxMsgId)) {
                 part = Msgid;
 
@@ -380,7 +343,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
                 (*(_msgid).begin()) = line;
             }
             // one of the quotation marks is missing
-            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgIdBorked))) {
+            else if (Q_UNLIKELY(line.contains(_rxMsgIdBorked))) {
                 part = Msgid;
 
                 // remove quotes at beginning and the end of the lines
@@ -422,7 +385,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
                 (*(_msgid).begin()) = line;
             }
             // one of the quotation marks is missing
-            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgIdBorked))) {
+            else if (Q_UNLIKELY(line.contains(_rxMsgIdBorked))) {
                 part = Msgid;
 
                 // remove quotes at beginning and the end of the lines
@@ -470,7 +433,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
                 _msgid.append(line);
             }
             // one of the quotation marks is missing
-            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgIdPluralBorked))) {
+            else if (Q_UNLIKELY(line.contains(_rxMsgIdPluralBorked))) {
                 part = Msgid;
                 _gettextPluralForm = true;
 
@@ -512,7 +475,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
 
                 _msgstrMultiline = line.isEmpty();
                 (*msgstrIt) = line;
-            } else if (Q_UNLIKELY(/*_testBorked&&*/ _gettextPluralForm && line.contains(_rxMsgStrPluralStartBorked))) {
+            } else if (Q_UNLIKELY(_gettextPluralForm && line.contains(_rxMsgStrPluralStartBorked))) {
                 part = Msgstr;
 
                 // remove quotes at beginning and the end of the lines
@@ -535,7 +498,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
                 break;
             }
             // a line of the msgid with a missing quotation mark
-            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgLineBorked))) {
+            else if (Q_UNLIKELY(line.contains(_rxMsgLineBorked))) {
                 recoverableError = true;
 
                 // remove quotes at beginning and the end of the lines
@@ -583,7 +546,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
                 _errorLine--;
                 _bufferedLine = line;
                 break;
-            } else if (Q_UNLIKELY(/*_testBorked&&*/ _gettextPluralForm && (line.contains(_rxMsgStrPluralBorked)))) {
+            } else if (Q_UNLIKELY(_gettextPluralForm && (line.contains(_rxMsgStrPluralBorked)))) {
                 // remove quotes at beginning and the end of the lines
                 line.remove(QRegularExpression(QStringLiteral("^msgstr\\[[0-9]\\]\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
@@ -600,7 +563,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
                 break;
             }
             // another line of the msgstr with a missing quotation mark
-            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgLineBorked))) {
+            else if (Q_UNLIKELY(line.contains(_rxMsgLineBorked))) {
                 recoverableError = true;
 
                 // remove quotes at beginning and the end of the lines
@@ -618,23 +581,6 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
         }
     }
 
-    /*
-       if(_gettextPluralForm)
-       {
-           qCDebug(LOKALIZE_LOG) << "gettext plural form:\n"
-                     << "msgid:\n" << _msgid.first() << "\n"
-                     << "msgid_plural:\n" << _msgid.last() << "\n" << endl;
-           int counter=0;
-           for(QStringList::Iterator it = _msgstr.begin(); it != _msgstr.end(); ++it)
-           {
-               qCDebug(LOKALIZE_LOG) << "msgstr[" << counter << "]:\n"
-                         << (*it) << endl;
-               counter++;
-           }
-       }
-      */
-
-    // qCDebug(LOKALIZE_LOG) << " NEAR RETURN";
     if (Q_UNLIKELY(error))
         return PARSE_ERROR;
     else if (Q_UNLIKELY(recoverableError))
@@ -642,5 +588,3 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
     else
         return OK;
 }
-
-// kate: space-indent on; indent-width 4; replace-tabs on;
